function [conc_stress] = ConcStress(x,conc_cblockf,beam_h,et,ec,conc_ec,n,code_formula,alpha1,conc_f1c,conc_f0)

strain = (et-ec)/beam_h*x+ec;

if strain > 0 % Compressive strain
    
    if strcmp(code_formula,'Parabola') == 1 % Parabolic concrete stress-strain curve [ACI 10.2.6, CSA 10.1.6, EN 3.1.7 (1)]
        
        if strain < conc_ec
            
            mod = 1-(1-strain/conc_ec)^n; % Parabolic function for concrete stress-strain curve
            
            if conc_f0 < 0 % If you have tensile strength (fibre-reinforced concrete)
                if mod < 0.2 && strain > conc_ec % If concrete has cracked and mod < 0.2
                    mod = 0.2;
                end
            end
            
            conc_stress = mod*conc_f1c;
            
        else
            
            conc_stress = conc_f1c;
            
        end
        
    elseif strcmp(code_formula,'Rectangle') == 1 % Rectangular concrete stress-strain curve [ACI 10.2.7, CSA 10.1.7, EN 3.1.7 (3)]
        
        if x < conc_cblockf
            conc_stress = alpha1*conc_f1c; % If you are within the compressive stress block
        else
            conc_stress = 0; % If you are within the tensile stress block
        end
        
    end
    
else % Tensile strain
    
    conc_stress = conc_f0;
    
end

end